/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.component.context;

import java.util.Hashtable;

import javax.naming.Binding;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.Name;
import javax.naming.NameClassPair;
import javax.naming.NameParser;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;

/**
 * This class inherits from an InitialContext and delegates method calls to a JNDI subcontext.
 * @author Olivier Fabre - EBM WebSourcing
 */
public class ComponentInitialContext extends InitialContext {

    public ComponentInitialContext(Context usersContext) throws NamingException {
        this.usersContext = usersContext;
    }

    protected Context usersContext;

    @Override
    public Object addToEnvironment(String propName, Object propVal) throws NamingException {
        return usersContext.addToEnvironment(propName, propVal);
    }

    @Override
    public void bind(Name name, Object obj) throws NamingException {
        usersContext.bind(name, obj);
    }

    @Override
    public void bind(String name, Object obj) throws NamingException {
        usersContext.bind(name, obj);
    }

    @Override
    public void close() throws NamingException {
        usersContext.close();
    }

    @Override
    public Name composeName(Name name, Name prefix) throws NamingException {
        return usersContext.composeName(name, prefix);
    }

    @Override
    public String composeName(String name, String prefix) throws NamingException {
        return usersContext.composeName(name, prefix);
    }

    @Override
    public Context createSubcontext(Name name) throws NamingException {
        return usersContext.createSubcontext(name);
    }

    @Override
    public Context createSubcontext(String name) throws NamingException {
        return usersContext.createSubcontext(name);
    }

    @Override
    public void destroySubcontext(Name name) throws NamingException {
        usersContext.destroySubcontext(name);
    }

    @Override
    public void destroySubcontext(String name) throws NamingException {
        usersContext.destroySubcontext(name);
    }

    @Override
    public Hashtable<?, ?> getEnvironment() throws NamingException {
        return usersContext.getEnvironment();
    }

    @Override
    public String getNameInNamespace() throws NamingException {
        return usersContext.getNameInNamespace();
    }

    @Override
    public NameParser getNameParser(Name name) throws NamingException {
        return usersContext.getNameParser(name);
    }

    @Override
    public NameParser getNameParser(String name) throws NamingException {
        return usersContext.getNameParser(name);
    }

    @Override
    public NamingEnumeration<NameClassPair> list(Name name) throws NamingException {
        return usersContext.list(name);
    }

    @Override
    public NamingEnumeration<NameClassPair> list(String name) throws NamingException {
        return usersContext.list(name);
    }

    @Override
    public NamingEnumeration<Binding> listBindings(Name name) throws NamingException {
        return usersContext.listBindings(name);
    }

    @Override
    public NamingEnumeration<Binding> listBindings(String name) throws NamingException {
        return usersContext.listBindings(name);
    }

    @Override
    public Object lookup(Name name) throws NamingException {
        return usersContext.lookup(name);
    }

    @Override
    public Object lookup(String name) throws NamingException {
        return usersContext.lookup(name);
    }

    @Override
    public Object lookupLink(Name name) throws NamingException {
        return usersContext.lookupLink(name);
    }

    @Override
    public Object lookupLink(String name) throws NamingException {
        return usersContext.lookupLink(name);
    }

    @Override
    public void rebind(Name name, Object obj) throws NamingException {
        usersContext.rebind(name, obj);
    }

    @Override
    public void rebind(String name, Object obj) throws NamingException {
        usersContext.rebind(name, obj);
    }

    @Override
    public Object removeFromEnvironment(String propName) throws NamingException {
        return usersContext.removeFromEnvironment(propName);
    }

    @Override
    public void rename(Name oldName, Name newName) throws NamingException {
        usersContext.rename(oldName, newName);
    }

    @Override
    public void rename(String oldName, String newName) throws NamingException {
        usersContext.rename(oldName, newName);
    }

    @Override
    public void unbind(Name name) throws NamingException {
        usersContext.unbind(name);
    }

    @Override
    public void unbind(String name) throws NamingException {
        usersContext.unbind(name);
    }

}
