/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task;

import java.io.File;
import java.net.URI;
import java.net.URL;

import org.ow2.petals.clientserverapi.configuration.ContainerConfiguration;
import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.system.SystemStateService;
import org.ow2.petals.microkernel.api.util.LoggingUtil;
import org.ow2.petals.systemstate.SystemStateException;

/**
 * This task creates state holder entry for component, service assembly or shared lib.
 * <p>
 * The task has got a non-robust approach : it stops at the first subtask failed<br />
 * and have the undo capability.<br />
 * Inputs : {@link Jbi}, archive {@link URI}
 * </p>
 * 
 * @author Olivier Fabre - EBM WebSourcing
 * @author Frederic Gardes - EBM WebSourcing
 */
public abstract class AbstractCreateStateHolderTask extends AbstractFileManipulationTask {

    /**
     * JBI Container :: Recovery Service
     */
    protected SystemStateService systemStateService = null;

    public AbstractCreateStateHolderTask(final LoggingUtil log,
            final SystemStateService systemStateSrv,
            final ContainerConfiguration containerConfiguration) {
        super(log, containerConfiguration);
        this.systemStateService = systemStateSrv;
    }

    public void execute(Context context) throws Exception {
        String entityName = context.getEntityName();
        String entityVersion = context.getEntityVersion();
        URL archiveUrl = context.getArchiveUrl();
        URL installUrl = context.getInstallUrl();

        createEntityStateHolder(entityName, entityVersion, installUrl, new File(archiveUrl
                .getPath()).getName());
    }

    protected abstract void createEntityStateHolder(String name, String version, URL installUrl,
            String archiveName) throws SystemStateException;

    public void undo(Context context) throws Exception {
        String entityName = context.getEntityName();
        String entityVersion = context.getEntityVersion();

        if (entityName != null) {
            try {
                this.deleteEntityStateHolder(entityName, entityVersion);
            } catch (Exception e) {
                this.log.error("Failed to revert a CreateStateHolderTask", e);
            }
        }
    }

    protected abstract void deleteEntityStateHolder(String name, String version) throws Exception;

}
