/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.deployment;

import java.util.List;

import org.ow2.petals.clientserverapi.configuration.ContainerConfiguration;
import org.ow2.petals.microkernel.api.extension.InstallationExtension;
import org.ow2.petals.microkernel.api.jbi.management.AdminService;
import org.ow2.petals.microkernel.api.jbi.messaging.registry.EndpointRegistry;
import org.ow2.petals.microkernel.api.system.SystemStateService;
import org.ow2.petals.microkernel.api.system.repository.RepositoryService;
import org.ow2.petals.microkernel.api.util.LoggingUtil;
import org.ow2.petals.microkernel.container.ContainerService;
import org.ow2.petals.microkernel.jbi.management.deployment.DeploymentServiceImpl;
import org.ow2.petals.microkernel.jbi.management.task.CopyArchiveToInstalledDirTask;
import org.ow2.petals.microkernel.jbi.management.task.CopyArchiveToWorkDirTask;
import org.ow2.petals.microkernel.jbi.management.task.DownloadTask;
import org.ow2.petals.microkernel.jbi.management.task.ExtractTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.CreateAndRegisterSULifeCycleTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.CreateSARepositoryTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.CreateSAStateHolderTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.CreateXMLDeploymentResultTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.DeployAllSUTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.DeploySUToComponentTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.ExtractSUsTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.RegisterAllConnectionTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.RegisterSALifeCycleTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.RenameSUsTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.RetrieveSAAndSUInstallRootsTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.deploy.SACheckPackageTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.CreateXMLUndeploymentResultTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.RemoveAllConnectionsTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.RemoveSAArchiveTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.RemoveSADirectoryTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.RemoveSAStateHolderTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.RetrieveSALifeCycleTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.UndeployAllSUsTask;
import org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy.UnregisterSALifeCycleTask;

/**
 * This Factory creates Deployment Tasks.
 * @author Olivier Fabre - EBM WebSourcing
 */
public class DeploymentTaskFactory {

    protected CreateXMLDeploymentResultTask createXMLDeploymentResultTask;

    protected SACheckPackageTask saCheckPackageTask;

    protected ExtractSUsTask extractSUsTask;

    protected DeployAllSUTask deployAllSUTask;

    protected RegisterSALifeCycleTask registerSALifeCycleTask;

    protected RegisterAllConnectionTask registerAllConnectionTask;

    protected CreateSAStateHolderTask createSAStateHolderTask;

    protected CopyArchiveToInstalledDirTask copyArchiveToInstalledDirTask;

    protected DeploySUToComponentTask deploySUToComponentTask;

    protected CreateAndRegisterSULifeCycleTask createAndRegisterSULifeCycleTask;

    protected RetrieveSAAndSUInstallRootsTask retrieveSAAndSUInstallRootsTask;

    protected RemoveAllConnectionsTask removeAllConnectionsTask;

    protected UndeployAllSUsTask undeployAllSUsTask;

    protected RemoveSADirectoryTask removeSAFolderTask;

    protected RemoveSAArchiveTask removeSAArchiveTask;

    protected RetrieveSALifeCycleTask retrieveSALifeCycleTask;

    protected UnregisterSALifeCycleTask unregisterSALifeCycleTask;

    protected RemoveSAStateHolderTask removeSAStateHolderTask;

    protected CreateXMLUndeploymentResultTask createXMLUndeploymentResultTask;

    private CreateSARepositoryTask copySAPackageToRepositoryTask;

    private ExtractTask extractTask;

    private RenameSUsTask renameSUsTask;

    private DownloadTask downloadTask;

    private CopyArchiveToWorkDirTask copyArchiveToWorkDirTask;

    public DeploymentTaskFactory(EndpointRegistry EndpointRegistry,
            DeploymentServiceImpl deploymentService, SystemStateService systemStateService,
            RepositoryService repositoryService, LoggingUtil log, AdminService adminService,
            ContainerService containerService, final ContainerConfiguration containerConfiguration,
            final List<InstallationExtension> installationExtensions) {

        /*
         * Create Tasks
         */

        this.createXMLDeploymentResultTask = new CreateXMLDeploymentResultTask();

        this.saCheckPackageTask = new SACheckPackageTask(log, systemStateService, adminService,
                containerConfiguration);

        this.extractSUsTask = new ExtractSUsTask(log, repositoryService, containerConfiguration);

        this.registerSALifeCycleTask = new RegisterSALifeCycleTask(log, adminService,
                containerService, containerConfiguration);

        this.deployAllSUTask = new DeployAllSUTask(log, this, containerConfiguration);

        this.registerAllConnectionTask = new RegisterAllConnectionTask(log, EndpointRegistry,
                containerConfiguration);

        this.createSAStateHolderTask = new CreateSAStateHolderTask(log, systemStateService,
                containerConfiguration);

        this.copyArchiveToInstalledDirTask = new CopyArchiveToInstalledDirTask(log,
                containerConfiguration, installationExtensions);

        this.deploySUToComponentTask = new DeploySUToComponentTask(log, adminService,
                containerConfiguration);

        this.createAndRegisterSULifeCycleTask = new CreateAndRegisterSULifeCycleTask(adminService);

        this.retrieveSAAndSUInstallRootsTask = new RetrieveSAAndSUInstallRootsTask(
                repositoryService);

        this.removeAllConnectionsTask = new RemoveAllConnectionsTask(log, EndpointRegistry,
                containerConfiguration);

        this.undeployAllSUsTask = new UndeployAllSUsTask(log, adminService, containerConfiguration);

        this.removeSAFolderTask = new RemoveSADirectoryTask(log, repositoryService,
                containerConfiguration);

        this.retrieveSALifeCycleTask = new RetrieveSALifeCycleTask(adminService);

        this.unregisterSALifeCycleTask = new UnregisterSALifeCycleTask(log, adminService,
                containerService, containerConfiguration);

        this.removeSAStateHolderTask = new RemoveSAStateHolderTask(log, systemStateService,
                containerConfiguration);

        this.createXMLUndeploymentResultTask = new CreateXMLUndeploymentResultTask();

        this.removeSAArchiveTask = new RemoveSAArchiveTask(log, containerConfiguration,
                installationExtensions);

        this.copySAPackageToRepositoryTask = new CreateSARepositoryTask(log, repositoryService,
                containerConfiguration);

        this.extractTask = new ExtractTask(log, containerConfiguration);

        this.renameSUsTask = new RenameSUsTask(repositoryService, log);

        // shared tasks
        this.downloadTask = new DownloadTask(log, containerConfiguration);

        this.copyArchiveToWorkDirTask = new CopyArchiveToWorkDirTask(log, containerConfiguration);
    }

    public DownloadTask getDownloadTask() {
        return this.downloadTask;
    }

    public CopyArchiveToWorkDirTask getCopyArchiveToWorkDirTask() {
        return copyArchiveToWorkDirTask;
    }

    public RenameSUsTask getRenameSUsTask() {
        return this.renameSUsTask;
    }

    public RegisterAllConnectionTask getRegisterAllConnectionTask() {
        return this.registerAllConnectionTask;
    }

    public DeployAllSUTask getDeployAllSUTask() {
        return this.deployAllSUTask;
    }

    public CopyArchiveToInstalledDirTask getCopyArchiveToInstalledDirTask() {
        return this.copyArchiveToInstalledDirTask;
    }

    public CreateAndRegisterSULifeCycleTask getCreateAndRegisterSULifeCycleTask() {
        return this.createAndRegisterSULifeCycleTask;
    }

    public ExtractSUsTask getExtractSUsTask() {
        return this.extractSUsTask;
    }

    public SACheckPackageTask getSaCheckPackageTask() {
        return this.saCheckPackageTask;
    }

    public CreateXMLDeploymentResultTask getCreateXMLDeploymentResultTask() {
        return this.createXMLDeploymentResultTask;
    }

    public RegisterSALifeCycleTask getRegisterSALifeCycleTask() {
        return this.registerSALifeCycleTask;
    }

    public CreateSAStateHolderTask getCreateSAStateHolderTask() {
        return this.createSAStateHolderTask;
    }

    public DeploySUToComponentTask getDeploySUToComponentTask() {
        return this.deploySUToComponentTask;
    }

    public RemoveAllConnectionsTask getRemoveAllConnectionsTask() {
        return this.removeAllConnectionsTask;
    }

    public UndeployAllSUsTask getUndeployAllSUTask() {
        return this.undeployAllSUsTask;
    }

    public RemoveSADirectoryTask getRemoveSAFolderTask() {
        return this.removeSAFolderTask;
    }

    public RetrieveSALifeCycleTask getRetrieveSALifeCycleTask() {
        return this.retrieveSALifeCycleTask;
    }

    public UnregisterSALifeCycleTask getUnregisterSALifeCycleTask() {
        return this.unregisterSALifeCycleTask;
    }

    public RemoveSAStateHolderTask getRemoveSAStateHolderTask() {
        return this.removeSAStateHolderTask;
    }

    public CreateXMLUndeploymentResultTask getCreateXMLUndeploymentResultTask() {
        return this.createXMLUndeploymentResultTask;
    }

    public RetrieveSAAndSUInstallRootsTask getRetrieveSAAndSUInstallRootsTask() {
        return this.retrieveSAAndSUInstallRootsTask;
    }

    public RemoveSAArchiveTask getRemoveSAArchiveTask() {
        return this.removeSAArchiveTask;
    }

    public CreateSARepositoryTask getCopySAPackageToRepositoryTask() {
        return this.copySAPackageToRepositoryTask;
    }

    public ExtractTask getExtractTask() {
        return this.extractTask;
    }
}
