/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.deployment.deploy;

import java.net.URL;

import org.ow2.petals.clientserverapi.configuration.ContainerConfiguration;
import org.ow2.petals.microkernel.api.system.SystemStateService;
import org.ow2.petals.microkernel.api.util.LoggingUtil;
import org.ow2.petals.microkernel.jbi.management.task.AbstractCreateStateHolderTask;
import org.ow2.petals.systemstate.SystemStateException;

/**
 * This task creates state holder for service assembly.
 *
 * <p>
 * This task MUST be executed with a {@link Context} containing:
 * <ul>
 * <li>service assembly name as entity name</li>
 * <li>archive URL</li>
 * <li>install URL</li>
 * </ul>
 * and returns no data in the {@link Context}.
 * </p>
 * 
 * @author Olivier Fabre - EBM WebSourcing
 */
public class CreateSAStateHolderTask extends AbstractCreateStateHolderTask {

    public CreateSAStateHolderTask(final LoggingUtil log,
            final SystemStateService systemStateService,
            final ContainerConfiguration containerConfiguration) {
        super(log, systemStateService, containerConfiguration);
    }

    @Override
    protected void createEntityStateHolder(String name, String version, URL installUrl,
            String archiveName) throws SystemStateException {
        this.systemStateService.createServiceAssemblyStateHolder(name, installUrl, archiveName);
    }

    @Override
    protected void deleteEntityStateHolder(String name, String version) throws Exception {
        this.systemStateService.deleteServiceAssemblyStateHolder(name);
    }

}
