/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.deployment.deploy;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.jbi.management.Task;
import org.ow2.petals.microkernel.api.jbi.management.XMLResult;
import org.ow2.petals.microkernel.api.jbi.management.XMLResult.MessageType;
import org.ow2.petals.microkernel.api.jbi.management.XMLResult.TaskResult;

/**
 * This task create framework task result. As we decide to create xml task
 * result only when deployment of the SA success, xml result only handles xml
 * component messages. All exceptions (caused by the deployment framework or
 * thrown by a component during the deployment of an su) are thrown and they
 * will stop the deployment process. It's a small violation of the
 * specification.
 * 
 * <p>
 * Inputs : {@link Jbi} <br/>
 * Outputs : * {@link XMLResult} <br/>
 * The task has a robust approach: it stops at the first subtask failed
 * and has undo capability.
 * </p>
 * 
 * @author Olivier Fabre - EBM WebSourcing
 * @author Frederic Gardes - EBM WebSourcing
 */
public class CreateXMLDeploymentResultTask implements Task {

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#execute(java.util.Map)
     */
    public void execute(Context context) throws Exception {
        String saName = context.getEntityName();
        XMLResult xmlResult = new XMLResult("deploy");
        this.createFrameworkTaskResult(saName, xmlResult);
        context.setXmlResult(xmlResult);
    }

    /**
     * Create the framework task result of the xml result message. Framework
     * task result is always a success because we decide that in other cases, an
     * exception is thrown.
     * 
     * @param saName
     *            the service assembly name
     * @param result
     *            framework task result
     */
    protected void createFrameworkTaskResult(String saName, XMLResult result) {
        result.addFrameworkTaskResult(TaskResult.SUCCESS, MessageType.INFO,
                "Successfully deployed service assembly : {1}", new String[] { saName }, null);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.processor.Task#undo(java.util.Map)
     */
    public void undo(Context context) throws Exception {
        context.setXmlResult(null);
    }

}
