/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.deployment.deploy;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URL;
import java.net.URLDecoder;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.jbi.descriptor.original.generated.ServiceUnit;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.jbi.management.ManagementException;
import org.ow2.petals.microkernel.api.jbi.management.Task;
import org.ow2.petals.microkernel.api.system.repository.RepositoryService;
import org.ow2.petals.microkernel.api.util.LoggingUtil;

/**
 * This task renames service unit packages into the repository to fits with
 * service unit ids in the JBI descriptor of the service assembly.
 * <p>
 * Inputs : {@link Jbi}, parent service assembly install root {@link URI} <br/>
 * Outputs : SU install roots {@link Map}.
 * </p>
 * 
 * @author Olivier Fabre - EBM WebSourcing
 */
public class RenameSUsTask implements Task {

    /**
     * logger wrapper
     */
    protected LoggingUtil log;

    public RenameSUsTask(RepositoryService repositoryService, LoggingUtil log) {
        super();
        this.log = log;
    }

    public void execute(final Context context) throws Exception {
        Jbi descriptor = context.getDescriptor();
        URL saInstallUrl = context.getInstallUrl();

        Map<String, URL> suInstallUrls = this.renameSUS(saInstallUrl, descriptor);
        context.setSuInstallUrls(suInstallUrls);
    }

    /**
     * Explode service unit packages into the repository
     * 
     * @param saInstallRoot
     *            the root {@link URI} of the service assembly
     * @param descriptor
     *            the service assembly descriptor
     * @return the map containing all SU install roots
     * @throws ManagementException
     *             if the repository service doesn't manage to expend su archive
     * @throws MalformedURLException 
     */
    @SuppressWarnings("deprecation")
    protected Map<String, URL> renameSUS(URL saInstallUrl, Jbi descriptor)
            throws ManagementException, MalformedURLException {
        Map<String, URL> suInstallUrls = new HashMap<String, URL>();
        List<ServiceUnit> sus = descriptor.getServiceAssembly().getServiceUnit();
        for (ServiceUnit unit : sus) {
            String saPath = URLDecoder.decode(saInstallUrl.getPath());
            File suPackageFile = new File(saPath, unit.getTarget().getArtifactsZip());
            File destFile = new File(saPath, unit.getIdentification().getName());
            suPackageFile.renameTo(destFile);
            suInstallUrls.put(unit.getIdentification().getName(), destFile.toURI().toURL());
        }
        return suInstallUrls;
    }


    public void undo(Context context) {
        // Nothing to do
    }

}
