/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.management.task.deployment.undeploy;

import org.ow2.petals.basisapi.exception.PetalsException;
import org.ow2.petals.clientserverapi.configuration.ContainerConfiguration;
import org.ow2.petals.microkernel.api.jbi.management.AdminService;
import org.ow2.petals.microkernel.api.jbi.management.Context;
import org.ow2.petals.microkernel.api.jbi.management.ManagementException;
import org.ow2.petals.microkernel.api.util.LoggingUtil;
import org.ow2.petals.microkernel.container.ContainerService;
import org.ow2.petals.microkernel.jbi.management.task.AbstractLoggableTask;

/**
 * This task removes the service assembly life cycle from the manager service SA Map.
 * <p>
 * Inputs : entity name {@link String}<br />
 * The task has got a non-robust approach : it tries to do all the subtasks
 * and doesn't have the undo capability.
 * </p>
 * 
 * @author Olivier Fabre - EBM WebSourcing
 * @author Frederic Gardes - EBM WebSourcing
 */
public class UnregisterSALifeCycleTask extends AbstractLoggableTask {

    /**
     * JBI Container :: JMX Agent Admin
     */
    protected AdminService adminService;

    /**
     * JBI Container :: Fractal container manager
     */
    protected ContainerService containerService;

    public UnregisterSALifeCycleTask(final LoggingUtil log, final AdminService adminService,
            final ContainerService containerService,
            final ContainerConfiguration containerConfiguration) {
        super(log, containerConfiguration);
        this.adminService = adminService;
        this.containerService = containerService;
    }

    public void execute(Context context) {
        String name = context.getEntityName();
        if (name != null) {
            try {
                this.adminService.unregisterServiceAssembly(name);
            } catch (ManagementException e) {
                this.log.error("Unable to unregister a service assembly", e);
            }

            /*
             * Remove the fractal component
             */
            try {
                this.containerService.removeServiceAssemblyLifeCycle(name);
            } catch (PetalsException e) {
                this.log.error("Unable to remove a fractal service assembly lifecycle", e);
            }
        }
    }

    public void undo(Context context) throws Exception {
        // TODO : register again the service assembly lifecycle
    }
}
