/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.messaging.control;

import javax.jbi.messaging.MessageExchange;

import org.ow2.petals.microkernel.api.jbi.messaging.ServiceEndpoint;

/**
 * @author Christophe Hamerling - EBM WebSourcing
 */
public interface ExchangeCheckerClient {

    /**
     * Query a component to check if it is ready to accept the exchange as a
     * consumer
     * 
     * @param internalEndpoint
     *            the endpoint to be used by the consumer; must be non null
     * @param exchange
     *            the proposed message exchange to be perfomed; must be non null
     * @return true if the provider component can perform the given exchange
     *         with the described consumer
     */
    boolean isExchangeWithConsumerOkayForComponent(ServiceEndpoint internalEndpoint,
            MessageExchange exchange);

    /**
     * Query a component to check if it is ready to accept the exchange as a
     * provider
     * 
     * @param internalEndpoint
     *            the endpoint to be used by the provider; must be non null
     * @param exchange
     *            the message exchange that is to be performed
     * @return true if this consumer component can interact with the described
     *         provider to perform the given exchange
     */
    boolean isExchangeWithProviderOkayForComponent(ServiceEndpoint internalEndpoint,
            MessageExchange exchange);

}
