/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.messaging.control;

import javax.jbi.messaging.MessageExchange;

import org.objectweb.fractal.fraclet.annotation.annotations.FractalComponent;
import org.objectweb.fractal.fraclet.annotation.annotations.Interface;
import org.objectweb.fractal.fraclet.annotation.annotations.LifeCycle;
import org.objectweb.fractal.fraclet.annotation.annotations.Provides;
import org.objectweb.fractal.fraclet.annotation.annotations.Requires;
import org.objectweb.fractal.fraclet.annotation.annotations.type.LifeCycleType;
import org.ow2.petals.jmx.api.api.JMXClient;
import org.ow2.petals.microkernel.api.communication.JMXService;
import org.ow2.petals.microkernel.api.util.LoggingUtil;
import org.ow2.petals.microkernel.util.ParameterCheckHelper;

/**
 * The JMX implementation of the echange checker client.
 * TODO: The exchange checker must be implemented via the transporter. 
 * 
 * @author Christophe Hamerling - EBM WebSourcing
 */
@FractalComponent
@Provides(interfaces = @Interface(name = "service", signature = ExchangeCheckerClient.class))
public class JMXExchangeCheckerClientImpl implements ExchangeCheckerClient {

    private LoggingUtil log;

    @Requires(name = "jmx")
    protected JMXService jmxService;

    /**
     * 
     */
    @LifeCycle(on = LifeCycleType.START)
    protected void start() {
        this.log = new LoggingUtil(java.util.logging.Logger.getLogger(Constants.FRACTAL_COMPONENT_LOGGER_NAME));
    }

    /**
     * 
     */
    @LifeCycle(on = LifeCycleType.STOP)
    protected void stop() {

    }

    /**
     * {@inheritDoc}
     */
    public boolean isExchangeWithConsumerOkayForComponent(
            org.ow2.petals.microkernel.api.jbi.messaging.ServiceEndpoint internalEndpoint,
            MessageExchange exchange) {
        this.log.start();
        ParameterCheckHelper.isNullParameterWithLog(internalEndpoint, "Endpoint", this.log);
        boolean test = true;
        try {
            // Retrieve a connection to the JMX server of the container were the
            // component is deployed
            final JMXClient server = this.jmxService.getJMXClient(internalEndpoint
                    .getLocation().getContainerName());
            // Ask the component if it is ok to accept the exchange
            test = server.getAdminServiceClient().isExchangeWithConsumerOkayForComponent(
                    internalEndpoint.getLocation().getComponentName(), internalEndpoint, exchange);
        } catch (final Exception e) {
            this.log.error("Problem in isExchangeWithConsumerOkayForComponent", e);
        }
        this.log.end();
        return test;
    }

    /**
     * {@inheritDoc}
     */
    public boolean isExchangeWithProviderOkayForComponent(
            org.ow2.petals.microkernel.api.jbi.messaging.ServiceEndpoint internalEndpoint,
            MessageExchange exchange) {
        this.log.start();
        if (internalEndpoint == null) {
            throw new IllegalArgumentException("Endpoint must be non null");
        }
        boolean test = true;
        try {
            // Retrieve a connection to the JMX server of the container were the
            // component is deployed
            final JMXClient server = this.jmxService.getJMXClient(internalEndpoint
                    .getLocation().getContainerName());
            // Retrieve the endpoint description
            test = server.getAdminServiceClient().isExchangeWithProviderOkayForComponent(
                    internalEndpoint.getLocation().getComponentName(), internalEndpoint, exchange);
        } catch (final Exception e) {
            this.log.error("Problem in isExchangeWithProviderOkayForComponent", e);
        }
        this.log.end();
        return test;
    }

}
