/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.messaging.routing.monitoring;

import javax.xml.namespace.QName;

/**
 * Router Monitor filter.
 * @author Roland Naudin - EBM WebSourcing
 */
public class RouterMonitorFilter {

    private final QName interfaceName;

    private final QName serviceName;

    private final String endpointName;

    private final QName operationName;

    private final boolean storeExchanges;

    public RouterMonitorFilter(final QName interfaceName, final QName serviceName, final String endpointName,
            final QName operationName, final boolean storeExchanges) {
        this.interfaceName = interfaceName;
        this.serviceName = serviceName;
        this.endpointName = endpointName;
        this.operationName = operationName;
        this.storeExchanges = storeExchanges;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        RouterMonitorFilter other = (RouterMonitorFilter) obj;
        if (this.endpointName == null) {
            if (other.endpointName != null)
                return false;
        } else if (!this.endpointName.equals(other.endpointName))
            return false;
        if (this.interfaceName == null) {
            if (other.interfaceName != null)
                return false;
        } else if (!this.interfaceName.equals(other.interfaceName))
            return false;
        if (this.operationName == null) {
            if (other.operationName != null)
                return false;
        } else if (!this.operationName.equals(other.operationName))
            return false;
        if (this.serviceName == null) {
            if (other.serviceName != null)
                return false;
        } else if (!this.serviceName.equals(other.serviceName))
            return false;
        
        return true;
    }

    public String getEndpointName() {
        return this.endpointName;
    }

    public QName getInterfaceName() {
        return this.interfaceName;
    }

    public QName getOperationName() {
        return this.operationName;
    }

    public QName getServiceName() {
        return this.serviceName;
    }
    
    

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((this.endpointName == null) ? 0 : this.endpointName.hashCode());
        result = prime * result + ((this.interfaceName == null) ? 0 : this.interfaceName.hashCode());
        result = prime * result + ((this.operationName == null) ? 0 : this.operationName.hashCode());
        result = prime * result + ((this.serviceName == null) ? 0 : this.serviceName.hashCode());
        result = prime * result + (this.storeExchanges ? 1231 : 1237);
        return result;
    }

    public boolean isStoreExchanges() {
        return this.storeExchanges;
    }

    @Override
    public String toString() {
        return "RouterMonitorFilter [endpointName=" + this.endpointName + ", interfaceName="
                + this.interfaceName + ", operationName=" + this.operationName + ", serviceName="
                + this.serviceName + "]";
    }
    
    

}
