/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.system.logging;

import java.util.Enumeration;
import java.util.LinkedList;
import java.util.List;
import java.util.logging.LogManager;
import java.util.logging.Logger;

import org.objectweb.fractal.fraclet.annotation.annotations.FractalComponent;
import org.objectweb.fractal.fraclet.annotation.annotations.Interface;
import org.objectweb.fractal.fraclet.annotation.annotations.LifeCycle;
import org.objectweb.fractal.fraclet.annotation.annotations.Provides;
import org.objectweb.fractal.fraclet.annotation.annotations.Requires;
import org.objectweb.fractal.fraclet.annotation.annotations.type.LifeCycleType;
import org.ow2.petals.commons.log.LoggerHelper;
import org.ow2.petals.microkernel.api.util.LoggingUtil;

/**
 * Implementation of the JMX API of the Petals Logging service.
 * 
 * @author Christophe DENEUX - Linagora
 */
@FractalComponent
@Provides(interfaces = @Interface(name = "service", signature = LoggingServiceMBean.class))
public class LoggingServiceMBeanImpl implements LoggingServiceMBean {

    /**
     * The logging service
     */
    @Requires(name = "logging", signature = LoggingService.class)
    protected LoggingService loggingService;
    
    /**
     * logger wrapper
     */
    private final LoggingUtil log = new LoggingUtil(Logger.getLogger(LoggingServiceImpl.class
            .getName()));

    /**
     * {@inheritDoc}
     */
    public String[] getLevels() {
        final List<String> supportedLevelNames = this.loggingService.getLevels();
        return supportedLevelNames.toArray(new String[supportedLevelNames.size()]);
    }
    
    /**
     * {@inheritDoc}
     */
    public String[][] getLoggers() {

        final Enumeration<String> loggerNamesEnum = LogManager.getLogManager().getLoggerNames();
        final List<String> loggerNames = new LinkedList<String>();
        while (loggerNamesEnum.hasMoreElements()) {
            loggerNames.add(loggerNamesEnum.nextElement());
        }
        final String[][] result = new String[loggerNames.size()][2];
        int i = 0;
        for (final String loggerName : loggerNames) {
            result[i][0] = loggerName;
            result[i++][1] = LoggerHelper.getLevelOrParentLevel(Logger.getLogger(loggerName))
                    .getName();
        }

        return result;
    }

    /**
     * Initializes and starts this JMX API implementation of logging service JMX
     * API
     */
    @LifeCycle(on = LifeCycleType.START)
    protected void start() {
        this.log.call();
    }
    
    /**
     * Stops this JMX API implementation of logging service JMX API
     */
    @LifeCycle(on = LifeCycleType.STOP)
    protected void stop() {
        this.log.call();
    }
}