/**
 * Copyright (c) 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.transport;

import static javax.jbi.messaging.MessageExchange.Role.PROVIDER;

import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

import org.ow2.petals.jbi.messaging.exchange.MessageExchangeWrapper;
import org.ow2.petals.probes.api.key.ProbeKey;

/**
 * Probe key of a transporter probes.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class TransporterProbeKey implements ProbeKey {

    private final String itf;

    private final String service;

    private final String endpoint;

    private final String status;

    /**
     * For optimization reason and as it's an immutable value, the string
     * representation of this key is computed at constructor level.
     */
    private final String[] keyAsStringArray;

    public TransporterProbeKey(final MessageExchangeWrapper exchangeWrapper) {

        if (PROVIDER.equals(exchangeWrapper.getRole())) {

            this.itf = exchangeWrapper.getInterfaceName().toString();

            final QName service = exchangeWrapper.getService();
            this.service = service == null ? null : service.toString();
        } else {
            // In consumer mode, only the endpoint is used to route the
            // exchange.
            this.itf = null;
            this.service = null;
        }

        final ServiceEndpoint endpoint = exchangeWrapper.getEndpoint();
        this.endpoint = endpoint == null ? null : endpoint.getEndpointName();
        this.status = exchangeWrapper.getStatus().toString();

        this.keyAsStringArray = new String[] { this.itf, this.service, this.endpoint, this.status };
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((endpoint == null) ? 0 : endpoint.hashCode());
        result = prime * result + ((itf == null) ? 0 : itf.hashCode());
        result = prime * result + ((service == null) ? 0 : service.hashCode());
        result = prime * result + ((status == null) ? 0 : status.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        TransporterProbeKey other = (TransporterProbeKey) obj;
        if (endpoint == null) {
            if (other.endpoint != null)
                return false;
        } else if (!endpoint.equals(other.endpoint))
            return false;
        if (itf == null) {
            if (other.itf != null)
                return false;
        } else if (!itf.equals(other.itf))
            return false;
        if (service == null) {
            if (other.service != null)
                return false;
        } else if (!service.equals(other.service))
            return false;
        if (status == null) {
            if (other.status != null)
                return false;
        } else if (!status.equals(other.status))
            return false;
        return true;
    }

    public String[] toStringArray() {
        return this.keyAsStringArray;
    }

    public String toReadableString() {
        return new StringBuilder(this.itf).append(", ").append(this.service).append(", ")
                .append(this.endpoint).append(", ").append(this.status).toString();
    }

}
