/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.container.thread;

import static org.easymock.EasyMock.expect;
import static org.easymock.EasyMock.expectLastCall;
import static org.easymock.classextension.EasyMock.createMock;
import static org.easymock.classextension.EasyMock.replay;
import static org.easymock.classextension.EasyMock.reset;
import static org.easymock.classextension.EasyMock.verify;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import javax.jbi.JBIException;
import javax.jbi.component.Bootstrap;
import javax.jbi.component.InstallationContext;
import javax.management.ObjectName;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.microkernel.api.container.thread.BootstrapThread;
import org.ow2.petals.microkernel.jbi.component.context.InstallationContextImpl;

/**
 * Installer thread unit test.
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class InstallerThreadTest {

    private BootstrapThread installerThread;

    private InstallationContext installContextMock;

    private Bootstrap bootstrapMock;

    /**
     * Test cleanUp
     * 
     */
    @Test
    public void testCleanUp() throws JBIException {
        installerThread.start();

        reset(bootstrapMock);
        bootstrapMock.cleanUp();
        expectLastCall();
        replay(bootstrapMock);

        try {
            installerThread.cleanUp();
        } catch (JBIException e) {
            fail(e.getMessage());
        }
        verify(bootstrapMock);
    }

    /**
     * Test init
     * 
     */
    @Test
    public void testInit() throws JBIException {
        installerThread.start();

        installContextMock = createMock(InstallationContextImpl.class);

        reset(bootstrapMock);

        bootstrapMock.init(installContextMock);
        expectLastCall();
        replay(bootstrapMock);

        try {
            installerThread.init(installContextMock);
        } catch (JBIException e) {
            fail(e.getMessage());
        }
        verify(bootstrapMock);
    }

    /**
     * Test onInstall
     * 
     */
    @Test
    public void testOnInstall() throws JBIException {
        installerThread.start();

        reset(bootstrapMock);
        bootstrapMock.onInstall();
        expectLastCall();
        replay(bootstrapMock);

        try {
            installerThread.onInstall();
        } catch (JBIException e) {
            fail(e.getMessage());
        }
        verify(bootstrapMock);
    }

    /**
     * Test onUninstall
     * 
     */
    @Test
    public void testOnUninstall() throws JBIException {
        installerThread.start();

        reset(bootstrapMock);
        bootstrapMock.onUninstall();
        expectLastCall();
        replay(bootstrapMock);

        try {
            installerThread.onUninstall();
        } catch (JBIException e) {
            fail(e.getMessage());
        }
        verify(bootstrapMock);
    }

    /**
     * Test getExtensionMBeanName
     * 
     */
    @Test
    public void testGetExtensionMBeanName() {
        installerThread.start();

        reset(bootstrapMock);
        ObjectName objectName = createMock(ObjectName.class);
        expect(bootstrapMock.getExtensionMBeanName()).andReturn(objectName);
        replay(bootstrapMock);

        ObjectName oName = installerThread.getExtensionMBeanName();
        assertEquals(oName, objectName);
        verify(bootstrapMock);
    }

    @Test
    public void testMultipleCalls() {
        installerThread.start();

        try {
            installerThread.onInstall();
            installerThread.onUninstall();
            installerThread.onInstall();
            installerThread.onUninstall();
            installerThread.onInstall();
            installerThread.onUninstall();
        } catch (JBIException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    @Before
    public void setUp() throws Exception {

        bootstrapMock = createMock(Bootstrap.class);

        installerThread = new BootstrapThread("installermock", bootstrapMock, 0, null);
    }

}
