/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.messaging.routing.mock;

import javax.jbi.JBIException;
import javax.jbi.component.Component;
import javax.jbi.component.ComponentContext;
import javax.jbi.component.ComponentLifeCycle;
import javax.jbi.component.ServiceUnitManager;
import javax.jbi.messaging.MessageExchange;
import javax.jbi.messaging.MessagingException;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;
import javax.xml.namespace.QName;

import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;

/**
 * Mock object of the Component.
 * @author ddesjardins - EBM WebSourcing
 */
public class ComponentMock implements Component, ComponentLifeCycle {

	private static final String ENDPOINT = "ClockEndpoint";

	// private DeliveryChannel channel;

	private static final String SERVICE = "ClockService";

	private String state = "Shutdown";

	private ComponentContext context;

	private ServiceUnitManager serviceUnitManager;

	@SuppressWarnings("unused")
	private ServiceEndpoint endpointReference;

	public ComponentContext getContext() {
		return context;
	}

	public ServiceEndpoint getEndpointReference() {
		return endpointReference;
	}

	public ObjectName getExtensionMBeanName() {
		ObjectName objectName = null;
		try {
			objectName = new ObjectName("test@test:name=test");
		} catch (MalformedObjectNameException e) {
			// Do nothing
		} catch (NullPointerException e) {
			// Do nothing
		}
		return objectName;
	}

	public ComponentLifeCycle getLifeCycle() {
		return this;
	}

	public Document getServiceDescription(ServiceEndpoint arg0) {
		return null;
	}

	public ServiceUnitManager getServiceUnitManager() {
		return serviceUnitManager;
	}

	public void setServiceUnitManager(ServiceUnitManager serviceUnitManager) {
		this.serviceUnitManager = serviceUnitManager;
	}

	public void init(ComponentContext context) throws JBIException {
		this.context = context;
	}

	public boolean isExchangeWithConsumerOkay(ServiceEndpoint arg0,
			MessageExchange arg1) {
		return true;
	}

	public boolean isExchangeWithProviderOkay(ServiceEndpoint arg0,
			MessageExchange arg1) {
		return true;
	}

	public ServiceEndpoint resolveEndpointReference(DocumentFragment arg0) {
		ServiceEndpoint result = null;
		return result;
	}

	public void shutDown() throws JBIException {
		state = "Shutdown";
	}

	public void start() throws JBIException {
		state = "Started";
		try {
			// this.channel = this.context.getDeliveryChannel();
			if (context != null) {
				endpointReference = this.context.activateEndpoint(new QName(
						SERVICE), ENDPOINT);
			}
		} catch (MessagingException e) {
			throw new JBIException(e);
		}
	}

	public void stop() throws JBIException {
		state = "Stopped";
	}

	public String getState() {
		return state;
	}
}
